@@ -2316,8 +2316,8 @@ enum
 };
 
 /* Define CC and CFLAGS which were used to build this version of GMP */
-#define __GMP_CC "gcc -std=gnu99"
-#define __GMP_CFLAGS "-O2 -I/build/openwrt-18.06/slaves/phase1/mvebu_cortexa53/build/staging_dir/host/include "
+#define __GMP_CC "gcc"
+#define __GMP_CFLAGS "-O2 -I/builder/mvebu_cortexa53/build/staging_dir/host/include "
 
 /* Major version number is the value of __GNU_MP__ too, above. */
 #define __GNU_MP_VERSION            6
